4. Bibliography — PyPAGO 1.0.1 documentation

# 4. Bibliography

PAGO has been used in the following studies:

[BDTC15] | Nicolas Barrier, Julie Deshayes, Anne-Marie Treguier, and Christophe Cassou. Heat budget in the North Atlantic subpolar gyre: Impacts of atmospheric weather regimes on the 1995 warming event. Progress in Oceanography, 130:75–90, 2015. URL: http://www.sciencedirect.com/science/article/pii/S0079661114001645, doi:https://doi.org/10.1016/j.pocean.2014.10.001.

[BP16] | Nicolas Barrier and Yann Petrenko, Anne A.and Ourmières. Strong intrusions of the Northern Mediterranean Current on the eastern Gulf of Lion: insights from in-situ observations and high resolution numerical modelling. Ocean Dynamics, 66(3):313–327, Mar 2016. URL: https://doi.org/10.1007/s10236-016-0921-7, doi:10.1007/s10236-016-0921-7.

[DCM14] | Julie Deshayes, Ruth Curry, and Rym Msadek. CMIP5 Model Intercomparison of Freshwater Budget and Circulation in the North Atlantic. Journal of Climate, 27(9):3298–3317, 2014. URL: https://doi.org/10.1175/JCLI-D-12-00700.1, arXiv:https://doi.org/10.1175/JCLI-D-12-00700.1, doi:10.1175/JCLI-D-12-00700.1.

[MSD+13] | J. Mignot, D. Swingedouw, J. Deshayes, O. Marti, C. Talandier, R. Séférian, M. Lengaigne, and G. Madec. On the evolution of the oceanic component of the IPSL climate models from CMIP3 to CMIP5: A mean state comparison. Ocean Modelling, 72(Supplement C):167 – 184, 2013. URL: http://www.sciencedirect.com/science/article/pii/S1463500313001637, doi:https://doi.org/10.1016/j.ocemod.2013.09.001.